
TODO: TODO_95_88_52_44: list server and client supported commands

There should be a way to know:
*   what commands are supported by client (current shell)
*   what commands are supported by server (it could be many servers due to FS_57_36_37_48 clients coexistence)


